@@ -26,6 +26,13 @@ private Q_SLOTS:
     void testRDate();
     void testDateTime_data();
     void testDateTime();
+    void testNotebook();
+    void testUidGeneration();
+    void testUidGenerationStability();
+    void testUidGenerationUniqueness();
+    void testIcalFormat();
+    void testNonTextCustomProperties();
+    void testAllDaySchedulingMessage();
 };
 
 #endif
