@@ -190,9 +190,7 @@ icalcomponent *ICalTimeZoneParser::icalcomponentFromQTimeZone(const QTimeZone &t
         // If there is no way to compile a complete list of transitions
         // transitions() can return an empty list
         // In that case try get one transition to write a valid VTIMEZONE entry.
-        if (transits.isEmpty()) {
-            qCDebug(KCALCORE_LOG) << "No transition information available VTIMEZONE will be invalid.";
-        }
+        qCDebug(KCALCORE_LOG) << "No transition information available VTIMEZONE will be invalid.";
     }
     if (earliest.isValid()) {
         // Remove all transitions earlier than those we are interested in
@@ -486,7 +484,7 @@ ICalTimeZone ICalTimeZoneParser::parseTimeZone(icalcomponent *vtimezone)
 
         // If the VTIMEZONE is a known IANA time zone don't bother parsing the rest
         // of the VTIMEZONE, get QTimeZone directly from Qt
-        if (QTimeZone::isTimeZoneIdAvailable(icalTz.id)) {
+        if (QTimeZone::isTimeZoneIdAvailable(icalTz.id) || icalTz.id.startsWith("UTC")) {
             icalTz.qZone = QTimeZone(icalTz.id);
             return icalTz;
         } else {
