@@ -87,11 +87,13 @@ public:
     bool recurTodo(Todo *todo);
 
     void deserialize(QDataStream &in);
+
+    bool validStatus(Incidence::Status) override;
 };
 
 void TodoPrivate::setDtDue(const QDateTime dd)
 {
-    if (dd != mDtDue || dd.timeSpec() != mDtDue.timeSpec()) {
+    if (!identical(dd, mDtDue)) {
         mDtDue = dd;
         mDirtyFields.insert(IncidenceBase::FieldDtDue);
     }
@@ -99,7 +101,7 @@ void TodoPrivate::setDtDue(const QDateTime dd)
 
 void TodoPrivate::setDtRecurrence(const QDateTime dr)
 {
-    if (dr != mDtRecurrence) {
+    if (!identical(dr, mDtRecurrence)) {
         mDtRecurrence = dr;
         mDirtyFields.insert(IncidenceBase::FieldRecurrenceId);
     }
@@ -129,6 +131,17 @@ void TodoPrivate::init(const TodoPrivate &other)
     mPercentComplete = other.mPercentComplete;
 }
 
+bool TodoPrivate::validStatus(Incidence::Status status)
+{
+    constexpr unsigned validSet
+        = 1u << Incidence::StatusNone
+        | 1u << Incidence::StatusNeedsAction
+        | 1u << Incidence::StatusCompleted
+        | 1u << Incidence::StatusInProcess
+        | 1u << Incidence::StatusCanceled;
+    return validSet & (1u << status);
+}
+
 //@endcond
 
 Todo::Todo()
@@ -171,7 +184,7 @@ bool Todo::equals(const IncidenceBase &todo) const
     } else {
         // If they weren't the same type IncidenceBase::equals would had returned false already
         const Todo *t = static_cast<const Todo *>(&todo);
-        return ((dtDue() == t->dtDue() && dtDue().timeSpec() == t->dtDue().timeSpec()) || (!dtDue().isValid() && !t->dtDue().isValid()))
+        return identical(dtDue(), t->dtDue())
             && hasDueDate() == t->hasDueDate()
             && hasStartDate() == t->hasStartDate() && ((completed() == t->completed()) || (!completed().isValid() && !t->completed().isValid()))
             && hasCompletedDate() == t->hasCompletedDate() && percentComplete() == t->percentComplete();
@@ -309,13 +322,13 @@ QDateTime Todo::completed() const
 
 void Todo::setCompleted(const QDateTime &completed)
 {
-    update();
     Q_D(Todo);
-    if (!d->recurTodo(this)) {
+    if (!d->recurTodo(this)) { // May indirectly call update()/updated().
+        update();
         d->setPercentComplete(100);
         d->setCompleted(completed);
+        updated();
     }
-    updated();
     if (status() != StatusNone) {
         setStatus(StatusCompleted); // Calls update()/updated()
     }
@@ -440,7 +453,14 @@ void Todo::setDtRecurrence(const QDateTime &dt)
 QDateTime Todo::dtRecurrence() const
 {
     Q_D(const Todo);
-    return d->dtRecurrence().isValid() ? d->dtRecurrence() : d->dtDue();
+    auto dt = d->dtRecurrence();
+    if (!dt.isValid()) {
+        dt = IncidenceBase::dtStart();
+    }
+    if (!dt.isValid()) {
+        dt = d->dtDue();
+    }
+    return dt;
 }
 
 bool Todo::recursOn(const QDate &date, const QTimeZone &timeZone) const
